class AdminsController < ApplicationController

  before_action :set_remote_user
  before_action :set_roles, :set_page_title, :set_breadcrumbs_admins
  before_action :require_admin

  # GET /admins
  def index
  end

  # GET /admins/stats
  def stats
    @breadcrumbs.push(
      ["Statistics", ""]
    )
    @spconfigs_total    = Spconfig.all.size
    @spconfigs_disabled = Spconfig.where(:disabled => true).size
    @spconfigs_enabled  = Spconfig.where(:disabled => false).size
    @spconfigs_enc_exceptions = Spconfig.where(:encryption_exception => true).size
    @spconfigs_legacy   = Spconfig.where(:is_legacy => true).size
  end

  # GET /admins/exportinfo
  def exportinfo
    @breadcrumbs.push(
      ["Exported File information", ""]
    )

    @file_infos = []
    # 1. Combined metadata files
    basepath = Rails.configuration.sp_metadatafile_basedir
    metadata_files = Spconfig.metadata_type_to_basename()
    metadata_files.each do |type, basename|
      info = {}
      filepath = File.join(basepath, basename)
      filepath = filepath.to_s() + ".xml"
      info["path"] = filepath
      if (File.exist?(filepath)) then
        info["mtime"]   = File.mtime(filepath)
        info["purpose"] = "Metadata file (#{type})"
      else
        info["mtime"]   = nil
        info["purpose"] = nil
      end
      @file_infos.append(info)
    end

    # 2. AWS account role mapping
    basepath = Rails.configuration.awsaccounts_git_local_path
    basename = Rails.configuration.awsaccounts_git_local_name
    filepath = File.join(basepath, basename, 'attribute-resolver-amazon-auto.xml')
    info = {}
    info["path"] = filepath
    if (File.exist?(filepath)) then
      info["mtime"]   = File.mtime(filepath)
      info["purpose"] = "Workgroup/AWS accounts role mapping"
    else
      info["mtime"]   = nil
      info["purpose"] = nil
    end
    @file_infos.append(info)

    # 3. Auto-entitlement attribute-filter file
    basepath = Rails.configuration.sp_entitlements_xml_file_basedir
    basename = Rails.configuration.sp_entitlements_xml_file_basename
    filepath = File.join(basepath, basename)
    info = {}
    info["path"]    = filepath
    if (File.exist?(filepath)) then
      info["mtime"]   = File.mtime(filepath)
      info["purpose"] = "Auto-entitlements attribute-filter file"
    else
      info["mtime"]   = nil
      info["purpose"] = nil
    end

    if (AdminConfiguration.ae_enabled?()) then
    end
    @file_infos.append(info)
  end

  def set_breadcrumbs_admins()
    @breadcrumbs = Utility.first_level_breadcrumb
    @breadcrumbs.push(['Administrative Functions', '/admins/index'])
    @model_name = 'admins'
  end

  def require_admin()
    if (!@is_admin) then
      redirect_to :controller => 'errors', :action => 'forbidden'
    end
  end

end
