class ApplicationController < ActionController::Base
  require 'utility'

  before_action :set_start_time

  # Prevent CSRF attacks by raising an exception.
  # For APIs, you may want to use :null_session instead.
  protect_from_forgery with: :exception

  # act_as_admin returns true if the current user is in the admin list AND
  # the act_as_admin session variable is true. Otherwise, returns false.
  def act_as_admin()
    if (session[:act_as_admin] and Utility.admin?(get_REMOTE_USER())) then
      return true
    else
      return false
    end
  end

  protected
    # All these methods are available to all controllers.

    # Use request.env rather than ENV. ENV seems to get values from other
    # Apache processes confusing the application about who is really logged
    # in.
    #
    # We define the GLOBAL variables $remote_env (for the entire environment)
    # and $remote_user (REMOTE_USER) for use in places (e.g., lib/utility.rb)
    # that do not have access to the request object.
    def set_remote_user
      $remote_env  = request.env
      $remote_user = request.env['REMOTE_USER']

      # Die if $remote_user is not set.
      if ($remote_user.blank?()) then
        raise "cannot continue as REMOTE_USER is not set"
      end

      Utility.logger.info("REMOTE_USER is #{$remote_user}")

      # Also set the applications this user can see.
      $visible_applications = Utility.visible_applications($remote_user)
      Utility.logger.info("$visible_applications is #{$visible_applications.inspect()}")
    end

    # This is used by paper_trail. Make sure to call this AFTER set_remote_user
    def current_user
      return $remote_user
    end

    def set_roles
      @is_admin          = false
      @is_readonly_admin = false
      @is_writer         = false

      remote_user        = Utility.get_REMOTE_USER()

      if (Utility.admin?(remote_user)) then
        @is_admin = true
      elsif (Utility.readonly_admin?(remote_user)) then
        @is_readonly_admin = true
      end

      if (Utility.can_write?()) then
        @is_writer = true
      end
      Utility.logger.info("#{$remote_user} app_groups_that_can_write is #{@is_writer}")
      Utility.logger.info("#{$remote_user} is_admin is #{@is_admin}")
      Utility.logger.info("#{$remote_user} is_readonly_admin is #{@is_readonly_admin}")
    end

    def set_start_time
      @start_time = Time.now.to_f
    end

    def set_breadcrumbs(top_level)
      @breadcrumbs = Utility.first_level_breadcrumb
      @breadcrumbs.push([top_level, '/spconfigs/index'])
#      @breadcrumbs.push(['SP Configurations', '/spconfigs/index'])
      @model_name = 'spconfig'
    end

    def set_page_title
      @page_title      = Rails.application.config.page_title
      @page_title_path = spconfigs_path
    end

end
