class AwsidprovidersController < ApplicationController

  # The order of these before_actions is important.
  before_action :set_remote_user
  before_action :set_awsidprovider, only: [:show, :edit, :update, :destroy]
  before_action :set_breadcrumbs
  before_action :set_paper_trail_whodunnit
  before_action :set_roles

  # GET /awsidprovider/1
  # GET /awsidprovider/1.json
  def show
  end

  def edit
    @breadcrumbs.push([get_breadcrumb('edit'), ""])
  end

  # PATCH/PUT /awsidprovider/1
  # PATCH/PUT /awsidprovider/1.json
  def update
    @awsidprovider.attributes = awsidprovider_params

    respond_to do |format|
      if (@awsidprovider.save()) then
        format.html { redirect_to @awsidprovider.awsaccount, notice: 'successfully updated',
                      alert: '(changes should take effect within 15 minutes)' }
        format.json { render :show, status: :ok, location: @awsaccount}
      else
        @breadcrumbs.push([get_breadcrumb('edit'), ""])

        format.html { render :edit }
        format.json { render json: @awsidprovidererrors, status: :unprocessable_entity }
      end
    end
  end


  private

    # Use callbacks to share common setup or constraints between actions.
    def set_awsidprovider()
      @awsidprovider = Awsidprovider.find(params[:id])
      if (!can_access()) then
        redirect_to "/errors/forbidden_record"
        return
      end
    end

    def can_access()
      user = Utility.get_REMOTE_USER()

      # 1. user is an SPDB admin.
      if (Utility.admin?(user)) then
        return true
      end

      # 2. user is one (or more) of this models groups.
      awsaccount = @awsidprovider.awsaccount
      if (awsaccount.user_in_workgroups(user)) then
        return true
      end

      return false
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def awsidprovider_params()
      params.require(:awsidprovider).permit(awsrolemappings_attributes:
                                              [:id,
                                               :workgroup,
                                               :role,
                                               :notes,
                                               :_destroy],
                                        )
    end

    # Get the last part of the arn
    def get_arn_tail()
      arn = @awsidprovider.arn
      arn_pieces = arn.split('/')
      arn_tail = arn_pieces[1]
      return arn_tail
    end

    def set_breadcrumbs
      @breadcrumbs = Utility.first_level_breadcrumb

      awsaccount = @awsidprovider.awsaccount

      @breadcrumbs.push(['My AWS Accounts', awsaccounts_path])
      @breadcrumbs.push(["Account #{awsaccount.number}", edit_awsaccount_path(awsaccount.id)])
      @model_name = 'awsidprovider'
    end

    def get_breadcrumb(action)
      if (action == 'edit') then
        arn_tail = get_arn_tail()
        breadcrumb = "Edit mappings for #{arn_tail}"
        return breadcrumb.html_safe
      end
    end


end
