class FederationsController < ApplicationController
  before_action :set_remote_user, :set_roles, :set_breadcrumbs
  before_action :allow_access
  before_action :set_federation, only: [:show, :edit, :update, :destroy]

  # GET /federations
  # GET /federations.json
  def index
    @federations = Federation.all
  end

  # GET /federations/1
  # GET /federations/1.json
  def show
  end

  # GET /federations/new
  def new
    @federation = Federation.new
  end

  # GET /federations/1/edit
  def edit
  end

  # POST /federations
  # POST /federations.json
  def create
    @federation = Federation.new(federation_params)

    respond_to do |format|
      if @federation.save
        format.html { redirect_to @federation, notice: 'Federation was successfully created.' }
        format.json { render :show, status: :created, location: @federation }
      else
        format.html { render :new }
        format.json { render json: @federation.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /federations/1
  # PATCH/PUT /federations/1.json
  def update
    respond_to do |format|
      if @federation.update(federation_params)
        format.html { redirect_to @federation, notice: 'Federation was successfully updated.' }
        format.json { render :show, status: :ok, location: @federation }
      else
        format.html { render :edit }
        format.json { render json: @federation.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /federations/1
  # DELETE /federations/1.json
  def destroy
    @federation.destroy
    respond_to do |format|
      format.html { redirect_to federations_url, notice: 'Federation was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_federation
      @federation = Federation.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def federation_params
      params.require(:federation).permit(:name)
    end

    def allow_access
      # We allow access if this application is "visible" to non-admins OR
      # the current user is an admin.
      if (not($visible_applications.include?('federations') or @is_admin)) then
        redirect_to '/403'
      end
    end

    def set_breadcrumbs
      @breadcrumbs = Utility.first_level_breadcrumb
      @breadcrumbs.push(['Federations', '/federations/index'])
      @model_name = 'federation'
    end

end
