class IdpsController < ApplicationController
  before_action :set_remote_user, :set_roles, :set_breadcrumbs
  before_action :allow_access

  before_action :set_idp, only: [:show, :edit, :update, :destroy]

  # GET /idps
  # GET /idps.json
  def index
    @idps = Idp.all
  end

  def all
    @idps = Idp.all
    @breadcrumbs.push(
      ["All IdP Metadatas", ""]
    )
  end

  # GET /idps/1
  # GET /idps/1.json
  def show
    @certificates = Utility.get_certificate_objects_from_metadata(@idp.metadata)

    breadcrumb = %Q(IdP Configuration <span class="sphighlight">#{@idp.entityid}</span>)
    @breadcrumbs.push(
      [breadcrumb.html_safe, ""]
    )
  end

  # GET /idps/new
  def new
    @idp = Idp.new
    @breadcrumbs.push(
      ["New IdP Metadata", ""]
    )
  end

  # GET /idps/1/edit
  def edit

  end

  # POST /idps
  # POST /idps.json
  def create
    @idp = Idp.new(idp_params)

    respond_to do |format|
      if @idp.save
        format.html { redirect_to @idp, notice: 'Idp was successfully created.' }
        format.json { render :show, status: :created, location: @idp }
      else
        format.html { render :new }
        format.json { render json: @idp.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /idps/1
  # PATCH/PUT /idps/1.json
  def update
    respond_to do |format|
      if @idp.update(idp_params)
        format.html { redirect_to @idp, notice: 'Idp was successfully updated.' }
        format.json { render :show, status: :ok, location: @idp }
      else
        format.html { render :edit }
        format.json { render json: @idp.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /idps/1
  # DELETE /idps/1.json
  def destroy
    @idp.destroy
    respond_to do |format|
      format.html { redirect_to idps_url, notice: 'Idp was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_idp
      @idp = Idp.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def idp_params
      params.require(:idp).permit(
        :entityid,
        :metadata,
        :url,
        :notes,
      )
    end

    def set_breadcrumbs
      @breadcrumbs = Utility.first_level_breadcrumb
      @breadcrumbs.push(['IdP Configurations', '/idps'])
      @model_name = 'idp'
    end

    def allow_access
      # We allow access if this application is "visible" to non-admins OR
      # the current user is an admin.
      if (not($visible_applications.include?('idps') or @is_admin)) then
        redirect_to '/403'
      end
    end

end
