module ApplicationHelper

  def button_class(class_name)
    class_name_to_button_class = {
      'awsaccounts' => 'btn btn-launch spdb-btn spdb-btn-aws',
      'federations' => 'btn btn-launch spdb-btn spdb-btn-federations',
      'idps'        => 'btn btn-launch spdb-btn spdb-btn-idps',
    }

    return class_name_to_button_class[class_name.downcase()]
  end

  def field_label(field, text)
    tool_tip = help_tool_tip(field)
    result = "<strong >#{text} #{tool_tip}:</strong>"
    return result
  end

  def remove_line_feeds(text)
    if (text.nil?())
      return text
    else
      return text.gsub(/\n/, ' ')
    end
  end

  def help_tool_tip(tag_name)
    message = help_for_tag(tag_name)
    message = remove_line_feeds(message)
    span_element = %Q[<span title="#{message}"> [?]</span>]
    return span_element
  end

  def help_for_messages(tag_name)
    valid_until_lower_limit_text = Rails.configuration.valid_until_lower_limit_text
    valid_until_upper_limit_text = Rails.configuration.valid_until_upper_limit_text
    maximum_entitlements         = Rails.configuration.maximum_entitlements
    #
    help_messages = {
     :metadata => <<-eoa,
The Service Provider's metadata. This must be a valid SAML 2.0 XML
string.
This is a REQUIRED field.
eoa
     :entityid => <<-eoa,
The Service Provider's entityId. This serves to uniquely identify the
Service Provider to the Identity Provider and must be a URL.
eoa
     :entityid_md5sum => <<-eoa,
This the MD5 hash of the entityID string. This is useful for
setting up Cardinal Key required workgroups.
eoa
     :disabled => <<-eoa,
If an SP configuration is disabled its metadata will be removed from the IdP.
Use this when you want to temporarily disable this SP but not delete
it entirely.
eoa
     :login_url => <<-eoa,
The URL used to login to the protected application.
eoa
     :contact_email => <<-eob,
A Mailman address or other group-based e-mail address.
Notifications about system issues, certificate expirations, or other
technical and administrative questions will be sent to this address.
This is a REQUIRED field.
eob
     :comments => <<-eob,
Provide short description of your application and/or any specific
configuration requirements.
eob
     :owned_by => <<-eob,
The SUNet ID of the user who created this entry. Only this user will be
able to see or modify this entry.
eob
     :sign_responses => <<-eob,
If the Service Provider wants the Identity Provider's responses to be
signed, this box must be checked. If you are unsure whether to check this
box or not, contact your Service Provider's technical support.
eob
     :encrypt_assertions => <<-eob,
If the Service Provider wants the Identity Provider's assertions to be
encrypted, this box must be checked. If you are unsure whether to check this
box or not, contact your Service Provider's technical support.
eob
     :sign_assertions => <<-eob,
If the Service Provider wants the Identity Provider's assertions to be
signed, this box must be checked. If you are unsure whether to check this
box or not, contact your Service Provider's technical support.
eob
     :created_at => <<-eob,
The date and time this record was created.
eob
     :updated_at => <<-eob,
The date and time this record was last changed.
eob
     :created_by => <<-eob,
The user who created this record.
eob
     :updated_by => <<-eob,
The user who last changed this record.
eob
     :acs_endpoint => <<-eob,
Assertion Consumer Service Endpoints - These are the locations to which the
IdP will eventually send the user at the Service Provider.
eob
     :workgroup => <<-eob,
Add or remove Stanford Workgroups that have privileges to manage this
resource. At least one of the workgroups must be non-personal
(i.e., does not start with ~) to prevent
SP configurations being orphaned by any one person leaving Stanford.
You can see a list of workgroups you belong to at the
Workgroup Manager web site
<a href="https://workgroup.stanford.edu/">https://workgroup.stanford.edu/</a>.
eob
     :entitlement => <<-eob,
Add or remove Stanford Workgroups to be released to this Service Provider.
For each workgroup the workgroup name will be added to the
eduPersonEntitlement multi-valued attribute sent to this Service Provider
if the current authenticated user is in
the workgroup. Some workgroups are private and cannot be released.
Note that if the "Allow Workgroup Release?" field
is set to FALSE then these workgroups will not be released.
eob
     :is_legacy => <<-eob,
If true this is a "legacy" configuration, that is, one added before the
blanket release policy. This field is editable only by SPDB admins.
eob
     :cert => <<-eob,
Expiration and usage information about the certificates in your
metadata. It is best practice to use a self-signed certificate that
expires no sooner than four years.
eob
     :self_signed_cert => <<-eob,
It is best practice to use a self-signed certificate that
expires no sooner than four years.
eob
     :valid_until => <<-eob,
Service Provider metadata should have a validUntil attribute that
indicates when the metadata is no longer valid.
After the validUntil date the IdP will not recognize your SP's metadata.
If used the validUntil attribute must be set to
a date at least #{valid_until_lower_limit_text} but not more
than #{valid_until_upper_limit_text} into the future.
eob
     :instance => <<-eob,
The AWS instance these mappings belong to. Will usually be "AWS" but
could also be "GovCloud".
eob
     :account_number => <<-eob,
The AWS account number. Must be exactly 12 digits.
eob
     :account_master => <<-eob,
If this account is a sub-account, put the master account number in this
field.
eob
     :account_nickname => <<-eob,
A short name to help identify this AWS account.
eob
     :id_provider => <<-eob,
The AWS SAML Identity Provider. This is automatically derived from the
account number.
eob
     :mappings => <<-eob,
These are the Stanford Workgroup to AWS IAM mappings. Each one consists
of the pair (workgroup, AWS role ARN).
eob
     :awsaccount_notes => <<-eob,
Any extra notes concerning this AWS account, for example, who are the
primary administrators.
eob
     :encryption_exception => <<-eob,
This SP has been granted an encryption exception meaning that all
certificate issues (expired, missing, etc.) are ignored when saving the
configuration.  This setting is only available to SPDB administrators.
eob
     :ignore_valid_until_issues => <<-eob,
Ignore validUntil attribute issues (expired, missing, etc.) when saving the configuration.
This option is only available to SPDB administrators.
eob
     :ignore_entityid_format_issues => <<-eob,
Ignore issues with the format of the entityID;
for example, allow an entityID that is not an absolute URI.
We only enforce this requirement on NEW registrations.
See also <a href="https://www.incommon.org/federation/mrps/">InCommon
Metadata Registration Practice Statement</a>.
eob
     :force_save => <<-eob,
Check this box to force a save. This will re-run the
validations and re-save all the fields even if you did not
update any of the fields.
eob
     :allow_entitlement_release => <<-eob,
This record's entitlements will be released in the
auto-entitlements file if, and only if, this box is checked.
Also, entitlements can be edited if, and only if, this box is checked.
eob
     :allow_unlimited_entitlements => <<-eob,
If this record is allowed to release entitlements and this checkbox
is checked, then no limit will be placed on the number of entitlements
that can be released to this SP; if unchecked then a maximum of
#{maximum_entitlements} entitlements can be released.
This checkbox can only be changed by
an SPDB administrator.
eob
     :workgrouptorole => <<-eob,
The mapping of a Stanford Workgroup to an AWS IAM role.
The first element is a Stanford Workgroup name. The second element is
the ARN of an AWS IAM role. The third element is optional and is for any
extra notes you may want to add concerning this mapping.
eob
     :idps_entityid => <<-eob,
The entity Id of this Identity Provider.
eob
     :idps_metadata => <<-eob,
The IdP SAML 2.0 metadata for this Identity Provider.
eob
     :idps_cert => <<-eob,
Information on all certificates contained in this IdPs metadata.
eob
     :idps_url => <<-eob,
The URL where this IdP metadata can be downloaded.
eob
     :idps_comments => <<-eob,
Any extra information for this IdP.
eob
     :idps_account_nickname => <<-eob,
A short description of this AWS account.
eob
     :copied_to_clipboard => <<-eob,
Copied to clipboard.
eob
    }

    return help_messages[tag_name]
  end

  def help_for_tag_old(tag_name)
    message = help_for_messages(tag_name)

    modal_element = %Q[<div id="#{tag_name}_text" class="modal" role="dialog"><div class="modal-dialog modal-dialog-centered" role="document"><div class="modal-content"><div class="modal-body">#{message}</div></div></div></div>]
    return modal_element
  end

  def help_for_tag(tag_name)
    message = help_for_messages(tag_name)

    modal_element = <<-EOM
<div class="modal fade" id="info_modal_#{tag_name}" tabindex="-1"
     role="dialog" aria-labelledby="modal_body_div_#{tag_name}" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-body" id="modal_body_div_#{tag_name}">
        #{message}
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary btn-sm" data-dismiss="modal">Close</button>
      </div>
    </div>
  </div>
</div>
EOM
    return modal_element
  end

  def help_for_info(tag_name)
    info_link = <<-EOM
<a href="#" data-toggle="modal" data-target="#info_modal_#{tag_name}"><img
   src="/assets/info_icon.png" alt="Help for #{tag_name}" title="Help for #{tag_name}"
   style="padding-bottom: 0px; padding-left: 3px"/></a>
EOM
    return info_link
  end

  def utc_to_local_time(utc_time)
    utc_time.in_time_zone("Pacific Time (US & Canada)")
  end

end
