class CertExpirationMailer < ActionMailer::Base
  default from: "saml-announce@lists.stanford.edu"

  def warning_email(spconfig:, day_window: 30, email_override: nil, dryrun: true)
    spdb_url         = 'https://spdb.stanford.edu/spconfigs'
    @spurl           = "#{spdb_url}/#{spconfig.id}"
    @entityid        = spconfig.entityid
    @expiration_date = (Time.now + day_window.days).to_date().to_s()

    subject = "Notification of expiring SAML SP certificate (entityID: #{@entityid})"

    if (email_override.nil?()) then
      to_addresses = [spconfig.contact_email]
    else
      to_addresses = [email_override]
    end

    # Also send to the owner (but not if owner is nil or "auto-migration").
    if ((not spconfig.owned_by.nil?()) && (spconfig.owned_by != 'auto-migration')) then
      if (email_override.nil?()) then
        to_addresses.push("#{spconfig.owned_by}@stanford.edu")
      end
    end

    # Send to both contact_email and owner (but not to "auto-migrate)
    result = mail(to: to_addresses, subject: subject)
    return result
  end

end
