# the view for this mailer is
# app/views/spconfig_expiration_mailer/warning_email.text.erb

class SpconfigExpirationMailer < ActionMailer::Base
  default from: "saml-announce@lists.stanford.edu"

  def warning_email(spconfig:, only_expired:, day_window:, email_override: nil,
                    dryrun: true, cc_addresses: [])
    @entityid       = spconfig.entityid
    @expired        = only_expired
    @email_override = email_override
    @contact_email  = spconfig.contact_email

    # Set @spurl:
    case Rails.env
    when /prod/i
      @spdb_domain = 'spdb.stanford.edu'
    when /dev/i
      @spdb_domain = 'spdb-dev.stanford.edu'
    else
      @spdb_domain = "spdb-#{Rails.env}.stanford.edu"
    end
    @spurl      = "https://#{@spdb_domain}/spconfigs/#{spconfig.id}"
    @sp_helpurl = "https://#{@spdb_domain}/faq#validuntil"

    if (@expired)
      subject = "ALERT: SPDB SAML configuration has expired (entityId: #{@entityid})"
    else
      subject = "SPDB SAML configuration expiring in #{day_window} days (entityId: #{@entityid})"
      @expiration_date = (Time.now + day_window.days).to_date().to_s()
    end

    if (email_override.nil?()) then
      to_addresses = [spconfig.contact_email]
    else
      to_addresses = [email_override]
    end

    # Also send to the owner (but not if owner is nil or "auto-migration").
    if ((not spconfig.owned_by.nil?()) && (spconfig.owned_by != 'auto-migration')) then
      if (email_override.nil?()) then
        to_addresses.push("#{spconfig.owned_by}@stanford.edu")
      end
    end

    # Send to both contact_email and owner (but not to "auto-migrate)
    result = mail(to: to_addresses.uniq, subject: subject, cc: cc_addresses)
    return result
  end

end
