class AdminConfiguration < ActiveRecord::Base

  def to_s()
    if (not description) then
      desc = 'NO DESCRIPION'
    else
      desc = description
    end

    return <<~HEREDOC
      name:         #{name}
      value:        #{value}
      description:  #{desc}
      class:        #{self.typify.class}
    HEREDOC
  end

  # Convert the congiguration item into its proper class
  def typify()
    if (name =~ /auto-entitlements-enabled/) then
      if (value =~ /true/)
        return true
      else
        return false
      end
    else
      return value
    end
  end

  # If configuration not defined we default to TRUE.
  def self.ae_enabled_raw?()
    ac = AdminConfiguration.find_by(name: 'auto-entitlements-enabled')

    if (ac.nil?()) then
      return true
    end

    return ac.typify()
  end

  def self.ae_enabled?()
    # Because we call this query on every page load, we cache its value.
    # Be sure to invalidate this cache whenever we update the ae_enabled
    # setting (see ae_toggle below).
    if (true) then
      Rails.cache.fetch("ae_enabled", expires_in: 1.hour) do
        self.ae_enabled_raw?()
      end
    else
        self.ae_enabled_raw?()
    end
  end

  def self.ae_toggle()
    ac = AdminConfiguration.find_by(name: 'auto-entitlements-enabled')

    if (ac.nil?()) then
      raise "no auto-entitlements-enabled admin configuration found"
    end

    new_ac = ! ac.typify()
    ac.value = new_ac.to_s()
    ac.save()

    # Invalidate the ae_enabled cach.
    Utility.logger.info "ae_toggle is deleting ae_enabled cache"
    Rails.cache.delete("ae_enabled")

    return ac
  end

end
