require 'utility'

class Awsidprovider < ActiveRecord::Base
  belongs_to :awsaccount
  has_many   :awsrolemappings

  accepts_nested_attributes_for :awsrolemappings,
                                reject_if: :all_blank,
                                allow_destroy: true

  validates :arn, presence: {message: 'You must supply a valid provider ARN.'}

  after_save    :after_save_callback
  after_destroy :after_destroy_callback

  # Return true if this SAML id provider ends in "saml-provider/stanford-idp"
  def regular_prod?()
    return arn =~ %r{saml-provider/stanford-idp$}
  end

  private

  def after_save_callback
    Utility.logger.info 'awsidprovider change detected; touching the updatedtimes table'
    Awsrolemapping.touch()
  end

  def after_destroy_callback
    Utility.logger.info 'awsidprovider object deleted; touching the updatedtimes table'
    Awsrolemapping.touch()
  end
end
