require 'utility'
require 'privgroup'

class Awsowninggroup < ActiveRecord::Base
  belongs_to :awsaccount

  validate  :group_is_valid
  validate  :current_user_in_groups

  # In case we need to skip validating that the workgroup is in
  # LDAP (e.g., when doing an initial load), set this attribute
  # to true.
  attr_accessor :skip_workgroup_validation

  # Validate that the workgroup is a real group in the OpenLDAP groups tree.
  def group_is_valid
    Utility.logger.debug("checking that awsowninggroup #{workgroup} is in OpenLDAP")

    if (skip_workgroup_validation) then
      Utility.logger.debug('skipping validation')
    elsif (Privgroup.new(workgroup).valid?()) then
      Utility.logger.debug("good news: awsowninggroup #{workgroup} is in OpenLDAP")
    else
      Utility.logger.info("awsowninggroup #{workgroup} is NOT in OpenLDAP")
      errors.add(:workgroup, "workgroup '#{workgroup}' not a valid workgroup.")
    end
  end

  # Only allow workgroups that the user is a member of or is an
  # administrator of (unless the user is an SPDB admin).
  def current_user_in_groups
    user = Utility.get_REMOTE_USER()
    if (Utility.admin?(user)) then
      Utility.logger.debug('user is an admin so can save groups')
      return
    else
      Utility.logger.debug("checking access to awsowninggroup #{workgroup}")
      privgroup = Privgroup.new(workgroup)
      if (!privgroup.user_is_member?(user)) then
        message = "Current user (#{user}) is not a member or administrator of workgroup #{workgroup}."
        Utility.logger.debug(message)
        errors.add(:workgroup, message)
      end
    end
  end
end
