require 'utility'
require 'privgroup'

class Group < ActiveRecord::Base
  belongs_to :spconfig

  validate :group_is_valid

  # We no longer insist that the user updating the record
  # be a member of the workgroup added. It might be that support
  # group A wants to allow support group B to manage the spconfig but
  # the members of groups A and B are disjoint. That should be allowed.
  #
  # validate  :current_user_in_groups

  # Validate that the workgroup is a real group in the OpenLDAP groups tree.
  def group_is_valid
    Utility.logger.debug("checking that group #{workgroup} is in OpenLDAP")
    if (Privgroup.new(workgroup).valid?()) then
      Utility.logger.debug("good news: #{workgroup} is in OpenLDAP")
      return
    else
      Utility.logger.info("#{workgroup} is NOT in OpenLDAP")
      errors.add(:workgroup, "Workgroup '#{workgroup}' not a valid workgroup.")
    end
  end

  # Only allow workgroups that the user is a member of (unless the user is
  # an admin).
  def current_user_in_groups
    user = Utility.get_REMOTE_USER()
    if (Utility.admin?(user)) then
      Utility.logger.debug('user is an admin so can save groups')
      return
    else
      Utility.logger.debug("checking access to group #{workgroup}")
      privgroup = Privgroup.new(workgroup)
      if (!privgroup.user_is_member?(user)) then
        Utility.logger.debug("#{user} is not a member of #{workgroup}")
        errors.add(:workgroup, "Current user (#{user}) is not a member of workgroup #{workgroup}.")
      end
    end
  end
end
