class Idp < ActiveRecord::Base
  ## VALIDATIONS
  validate  :metadata_is_valid

  def metadata_is_valid
    # If the user has indicated that this SP is part of the InCommon
    # Federation, set metatadata to some default string and skip the rest
    # of the validation.

    if (metadata.nil? or metadata.empty?) then
      errors.add(:base, 'Metadata cannot be empty.')
      return
    end

    get_validation_results()

    if (!@saml_validation_errors.nil?)
      if (@saml_validation_errors.key?('300')) then
        # If the metadata is not valid XML skip the other errors.
        errors.add(:base, 'Metadata is not valid XML')
        return
      end
    end
  end

  protected

  def get_validation_results
    metadata_stripped = try_to_strip_xml_declaration(metadata)

    @metadata_validation_results = Utility.submit_metadata_for_validation(metadata_stripped)

    @idp_info               = @metadata_validation_results[0]
    @saml_validation_errors = @metadata_validation_results[1]

    Utility.logger.info("metadata validation results: #{@metadata_validation_results.inspect}")

    # Pre-populate entityid so we we can find it.
    if (@idp_info.key?('entityID'))
      self.entityid = @idp_info['entityID']
    end
  end

  # Returns the XML without the <?xml header if the XML is valid. If the
  # XML is _not_ valid simply returns the original XML string.
  def try_to_strip_xml_declaration(metadata_string)
    stripped_metadata = nil
    begin
      stripped_metadata = Utility.strip_xml_declaration(metadata_string)
    rescue
      stripped_metadata = nil
    end

    if (stripped_metadata.nil?()) then
      return metadata_string
    else
      return stripped_metadata
    end
  end
end
