require 'utility'
Rails.application.routes.draw do

  resources :idps do
    collection do
      get 'all'
    end
  end

  resources :federations

  # Route different people to different home pages.
  get "home", to: "spconfigs#index",
      constraints: lambda { |request| Utility.home_page(request.env['REMOTE_USER']) == "spconfigs#index" }

  get "home", to: "helps#home",
      constraints: lambda { |request| Utility.home_page(request.env['REMOTE_USER']) == "helps#home" }

  get "home", to: "idps#index",
      constraints: lambda { |request| Utility.home_page(request.env['REMOTE_USER']) == "idps#index" }

  get "home", to: "awsaccounts#index",
      constraints: lambda { |request| Utility.home_page(request.env['REMOTE_USER']) == "awsaccounts#index" }

  get "home", to: "federations#index",
      constraints: lambda { |request| Utility.home_page(request.env['REMOTE_USER']) == "federations#index" }


  resources :groups

  # Error page routes
  get 'errors/forbidden_record'
  get 'errors/forbidden'
  get 'errors/not_found'
  get 'errors/internal_server_error'

  match "/403", :to => "errors#forbidden",             :via => :all
  match "/404", :to => "errors#not_found",             :via => :all
  match "/500", :to => "errors#internal_server_error", :via => :all

  # Help pages
  get 'help'             => "helps#index"
  get 'configuration'    => "helps#configuration"
  get 'faq'              => "helps#faq"
  get 'help/awsaccounts' => "helps#awsaccounts"
  get 'help/index'       => "helps#index"

  # Special clear cache page
  get 'clearcache' => "helps#clearcache"

  # Be sure that extra routes come BEFORE "resources :spconfigs"
  match "/spconfigs/index",            to: "spconfigs#index",      via: [:get]
  match "/spconfigs/all",              to: "spconfigs#all",        via: [:get]
  match "/spconfigs/list",             to: "spconfigs#list",       via: [:get]
  match "/spconfigs/stats",            to: "spconfigs#stats",      via: [:get]
  match "/spconfigs/entitlementsxml",  to: "spconfigs#entitlementsxml", via: [:get]
  match "/spconfigs/:id/attributes",   to: "spconfigs#attributes", via: [:get]
  resources :spconfigs

  # Accounts
  match "/awsaccounts/all",  to: "awsaccounts#all",  via: [:get]
  match "/awsaccounts/list", to: "awsaccounts#list", via: [:get]
  resources :awsaccounts

  # Accounts
  resources :awsidproviders

  # AdminConfigurations
  match "/admin_configurations/ae",        to: "admin_configurations#ae",       via: [:get]
  match "/admin_configurations/aetoggle",  to: "admin_configurations#aetoggle", via: [:get]
  resources :admin_configurations

  # Administrative pages
  match "/admins",              to: "admins#index",   via: [:get]
  match "/admins/index",        to: "admins#index",   via: [:get]
  match "/admins/stats",        to: "admins#stats",   via: [:get]
  match "/admins/exportinfo",   to: "admins#exportinfo",      via: [:get]
  match "/admins/listincommon", to: "spconfigs#listincommon", via: [:get]

  # Put this LAST: make landing page the Helps controller action "home":
  root :to => redirect('/home')


  # The priority is based upon order of creation: first created -> highest priority.
  # See how all your routes lay out with "rake routes".

  # Example of regular route:
  #   get 'products/:id' => 'catalog#view'

  # Example of named route that can be invoked with purchase_url(id: product.id)
  #   get 'products/:id/purchase' => 'catalog#purchase', as: :purchase

  # Example resource route (maps HTTP verbs to controller actions automatically):
  #   resources :products

  # Example resource route with options:
  #   resources :products do
  #     member do
  #       get 'short'
  #       post 'toggle'
  #     end
  #
  #     collection do
  #       get 'sold'
  #     end
  #   end

  # Example resource route with sub-resources:
  #   resources :products do
  #     resources :comments, :sales
  #     resource :seller
  #   end

  # Example resource route with more complex sub-resources:
  #   resources :products do
  #     resources :comments
  #     resources :sales do
  #       get 'recent', on: :collection
  #     end
  #   end

  # Example resource route with concerns:
  #   concern :toggleable do
  #     post 'toggle'
  #   end
  #   resources :posts, concerns: :toggleable
  #   resources :photos, concerns: :toggleable

  # Example resource route within a namespace:
  #   namespace :admin do
  #     # Directs /admin/products/* to Admin::ProductsController
  #     # (app/controllers/admin/products_controller.rb)
  #     resources :products
  #   end
end
