# Export combined metadata file.
require 'utility'

# # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # #
def send_to_cloud_storage(cloud_provider, bucket_name, credentials_file, metadata_type)
  provider_to_script = {
    'aws' => '/usr/share/spdb/bin/send-metadata-to-s3',
    'gcp' => '/usr/share/spdb/bin/send-metadata-to-gcs',
  }

  if (not provider_to_script.key?(cloud_provider)) then
    Utility.logger.error("unrecognized cloud provider '#{cloud_provider}'")
    exit(1)
  end

  Utility.logger.info("[export_metadata] sending metadata type #{metadata_type} to #{cloud_provider}")

  metadata_type_to_source_file_path = {
    'combined'   => '/srv/www/spdb/metadata.xml',
    'legacy'     => '/srv/www/spdb/metadata-legacy.xml',
    'non-legacy' => '/srv/www/spdb/metadata-blanket.xml',
  }

  metadata_type_to_destination_file_name = {
    'combined'   => 'sp-metadata.xml',
    'legacy'     => 'sp-metadata-legacy.xml',
    'non-legacy' => 'sp-metadata-blanket.xml',
  }

  cmds = [
    provider_to_script[cloud_provider],
    Rails.env,
    bucket_name,
    metadata_type_to_source_file_path[metadata_type],
    metadata_type_to_destination_file_name[metadata_type],
    credentials_file,
  ]

  cmd = cmds.join(' ')
  Utility.logger.debug("[export_metadata] about to run command '#{cmd}'")

  stdout, stderr, p_status = Open3.capture3(cmd)
  rc = p_status.exitstatus()
  Utility.logger.debug("[#{stdout}][#{stderr}][#{p_status}][#{rc}]")

  if (rc == 0) then
    Utility.logger.debug("#{cloud_provider} upload command suceeded")
  else
    # An error.
    Utility.logger.error("#{cloud_provider} command '#{cmd}' failed: #{stderr}")
    exit(1)
  end
end

def upload_metadata_of_type(metadata_type)
  Utility.logger.info("[export_metadata] #{metadata_type} metadata was exported; send to cloud (maybe)")

  # AWS
  if (Rails.configuration.combined_metadata_to_s3_send) then
    bucket_name = Rails.configuration.combined_metadata_to_s3_bucket
    credentials = Rails.configuration.combined_metadata_to_s3_credentials
    Utility.logger.info("[export_metadata] sending metadata type #{metadata_type} to AWS S3")
    #send_to_cloud_storage('aws', bucket_name, credentials, metadata_type)
  else
    Utility.logger.info('[export_metadata] not sending metadata type #{metadata_type} to S3 (send disabled)')
  end

  # GCP
  if (Rails.configuration.combined_metadata_to_gcs_send) then
    bucket_name = Rails.configuration.combined_metadata_to_gcs_bucket
    credentials = Rails.configuration.combined_metadata_to_gcs_credentials
    Utility.logger.info('[export_metadata] sending metadata type #{metadata_type} to GCS')
    send_to_cloud_storage('gcp', bucket_name, credentials, metadata_type)
  else
    Utility.logger.info('[export_metadata] not sending metadata type #{metadata_type} to GCP (send disabled)')
  end

  return
end

# # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # ## # # # #

###
### STAGE 1: write to local file system.

# See if the environment variable FORCE_EXPORT is defined. If so, we
# force the export.
if (ENV.key?("FORCE_EXPORT")) then
  force_this_update = true
else
  force_this_update = false
end

# Spconfig.save_metadata_to_file()
metadata_type_to_was_written = Spconfig.save_metadatas_to_file(force_update: force_this_update)

# Make sure the permissions are correct
basepath = Rails.configuration.sp_metadatafile_basedir

cmd = "chown -R root.www-data #{basepath}"
`#{cmd}`

cmd = "chmod -R g+rw #{basepath}"
`#{cmd}`

###
### STAGE 2: write to Cloud.

# If the file was written, send it to Amazon S3 (maybe) and Google
# Cloud Storage (maybe).
Spconfig.metadata_type_to_basename.each  do |metadata_type, basename|
  if (metadata_type_to_was_written[metadata_type]) then
    Utility.logger.info("[export_metadata] processing metadata type #{metadata_type}")
    upload_metadata_of_type(metadata_type)
  else
    Utility.logger.info("[export_metadata] not time to send combined metadata type #{metadata_type} to any cloud provider")
  end
end
