class Notifications < Thor

  desc "test123 [mode, arg2]", "a test Thor function"
  method_option :override_email, :type => :string,  :default => nil
  method_option :dry_run,        :type => :boolean, :default => true
  def test123(mode, arg2)
    puts "Hello: #{mode} #{arg2}"
    puts options[:override_email]
  end


  ######################################################################
  #
  # Generate an e-mail if an SP configuration is expired or about to
  # expire (based on validUntil).
  #
  # From command line, to run with day_window set to 15 days:
  #
  #    RAILS_ENV=development thor notifications:spconfig_expirations --day-window=15 warning
  #
  # To override e-mail:
  #
  #    RAILS_ENV=development thor notifications:spconfig_expirations --email_override=adamhl@stanford.edu warning
  #
  # We skip sending notifications for configurations that are marked disabled.
  #
  # To Cc: some extra addresses:
  #
  #    RAILS_ENV=development thor notifications:spconfig_expirations --cc=johndoe@stanford.edu,janeroe@stanford.edu warning
  #
  # Note that if --email_override is used then the --cc option is ignored.
  #
  # When in "expired" mode don't send expired notices if the configuration
  # expired  more that --day_limit days ago.

  desc "sp_configurations [mode]", "send SP expiration notifications and warnings"
  method_option :dry_run,        :type => :boolean, :default => true
  method_option :day_window,     :type => :numeric, :default => 30
  method_option :day_limit,      :type => :numeric, :default => 30
  method_option :email_override, :type => :string,  :default => nil
  method_option :cc,             :type => :string,  :default => nil
  method_option :debug,          :type => :boolean, :default => false
  def spconfig_expirations(mode = 'expired')
    require File.expand_path('config/environment')
    if ((mode != 'expired') && (mode != 'warning')) then
      raise "mode passed is #{mode}; however, mode must be one of 'expired' or 'warning'"
    end

    dry_run        = options[:dry_run]
    day_window     = options[:day_window]
    day_limit      = options[:day_limit]
    email_override = options[:email_override]
    cc             = options[:cc]
    debug          = options[:debug]

    dbg = ->(msg) { if (debug) then print("DEBUG: #{msg}\n") end }

    dbg.call("mode:           #{mode}")
    dbg.call("dry_run:        #{dry_run}")
    dbg.call("day_window:     #{day_window}")
    if (email_override.blank?()) then
      dbg.call("email_override: BLANK")
    else
      dbg.call("email_override: #{email_override}")
    end
    if (cc.blank?()) then
      dbg.call("cc:             BLANK")
    else
      dbg.call("cc:             #{cc}")
    end

    if (mode == 'expired')
      only_expired = true
    else
      only_expired = false
    end

    dbg.call("we will be sending '#{mode}' notifications")

    if (dry_run) then
      dbg.call("we are running in DRY RUN mode")
    else
      dbg.call("we are running in ACTUAL (deliver mail) mode")
    end

    # Start of code that actually does stuff.
    now_utc = Time.now.utc

    if (not only_expired) then
      if (day_window.nil?()) then
        raise "error: missing day_window argment"
      end

      dbg.call("setting warning data window")
      day_window         = day_window.to_i()
      warning_date       = now_utc + day_window.days
      warning_date_plus1 = now_utc + (day_window + 1).days
      dbg.call("warning data window is (#{warning_date}, #{warning_date_plus1})")
    end

    # Get all spconfigs that are not disabled.
    spconfigs = Spconfig.where(disabled: false).order(:id).all()

    spconfigs.each do |spconfig|
      valid_until = spconfig.valid_until

      # Skip sp configurations with blank validUntil's.
      if (valid_until.blank?()) then
        next
      end

      if (only_expired) then
        # EXPIRED CONFIGURATIONS

        # We don't send expired notifications if the configuration
        # has been expired for too long.
        expired_limit_utc = valid_until + day_limit.days

        if ((valid_until < now_utc) and (now_utc <= expired_limit_utc)) then
          send_notification = true
        else
          send_notification = false
        end
      else
        # IN DATE WINDOW CONFIGURATIONS
        if ((valid_until < warning_date_plus1) and
            (valid_until >= warning_date)) then
          send_notification = true
        else
          send_notification = false
        end
      end

      if (send_notification) then
        dbg.call("sending notification for #{spconfig.id}")

        # Note that if we are overriding the e-mail then we omit
        # any Cc:'s.
        if (not cc.blank?() and email_override.blank?()) then
          cc_addresses = cc.split(',')
          dbg.call("cc_addresses is " + cc_addresses.join(', '))
        else
          cc_addresses = []
          dbg.call("no cc_addresses")
        end

        result = SpconfigExpirationMailer.warning_email(spconfig:       spconfig,
                                                        only_expired:   only_expired,
                                                        day_window:     day_window,
                                                        cc_addresses:   cc_addresses,
                                                        email_override: email_override)
        if (dry_run) then
          print result.to_s()
        else
          print result.deliver()
        end
      end
    end

  end

end
